==> zio-aws-apigatewayv2_2.12-5.17.130.7-sources.jar: zio/aws/apigatewayv2/model/GetRoutesResponse.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetRoutesResponse(
    items: Option[Iterable[zio.aws.apigatewayv2.model.Route]] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetRoutesResponse = {
    import GetRoutesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetRoutesResponse
      .builder()
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetRoutesResponse.ReadOnly =
    zio.aws.apigatewayv2.model.GetRoutesResponse.wrap(buildAwsValue())
}
object GetRoutesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetRoutesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetRoutesResponse =
      zio.aws.apigatewayv2.model.GetRoutesResponse(
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def items: Option[List[zio.aws.apigatewayv2.model.Route.ReadOnly]]
    def nextToken: Option[NextToken]
    def getItems
        : ZIO[Any, AwsError, List[zio.aws.apigatewayv2.model.Route.ReadOnly]] =
      AwsError.unwrapOptionField("items", items)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetRoutesResponse
  ) extends zio.aws.apigatewayv2.model.GetRoutesResponse.ReadOnly {
    override val items
        : Option[List[zio.aws.apigatewayv2.model.Route.ReadOnly]] = scala
      .Option(impl.items())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.apigatewayv2.model.Route.wrap(item)
        }.toList
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.apigatewayv2.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetRoutesResponse
  ): zio.aws.apigatewayv2.model.GetRoutesResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-apigatewayv2_2.12-5.17.183.1-sources.jar: zio/aws/apigatewayv2/model/GetRoutesResponse.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetRoutesResponse(
    items: Optional[Iterable[zio.aws.apigatewayv2.model.Route]] =
      Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetRoutesResponse = {
    import GetRoutesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetRoutesResponse
      .builder()
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetRoutesResponse.ReadOnly =
    zio.aws.apigatewayv2.model.GetRoutesResponse.wrap(buildAwsValue())
}
object GetRoutesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetRoutesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetRoutesResponse =
      zio.aws.apigatewayv2.model.GetRoutesResponse(
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def items: Optional[List[zio.aws.apigatewayv2.model.Route.ReadOnly]]
    def nextToken: Optional[NextToken]
    def getItems
        : ZIO[Any, AwsError, List[zio.aws.apigatewayv2.model.Route.ReadOnly]] =
      AwsError.unwrapOptionField("items", items)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetRoutesResponse
  ) extends zio.aws.apigatewayv2.model.GetRoutesResponse.ReadOnly {
    override val items
        : Optional[List[zio.aws.apigatewayv2.model.Route.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.items())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.apigatewayv2.model.Route.wrap(item)
          }.toList
        )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.apigatewayv2.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetRoutesResponse
  ): zio.aws.apigatewayv2.model.GetRoutesResponse.ReadOnly = new Wrapper(impl)
}
